pub struct ExecutionManagerConfig {Show 26 fields
pub trader_id: TraderId,
pub reconciliation: bool,
pub lookback_mins: Option<u64>,
pub reconciliation_instrument_ids: IndexSet<InstrumentId>,
pub filter_unclaimed_external: bool,
pub filter_position_reports: bool,
pub filtered_client_order_ids: IndexSet<ClientOrderId>,
pub generate_missing_orders: bool,
pub inflight_check_interval_ms: u32,
pub inflight_threshold_ms: u64,
pub inflight_max_retries: u32,
pub open_check_interval_secs: Option<f64>,
pub open_check_lookback_mins: Option<u64>,
pub open_check_threshold_ns: u64,
pub open_check_missing_retries: u32,
pub open_check_open_only: bool,
pub max_single_order_queries_per_cycle: u32,
pub single_order_query_delay_ms: u32,
pub position_check_interval_secs: Option<f64>,
pub position_check_lookback_mins: u64,
pub position_check_threshold_ns: u64,
pub position_check_retries: u32,
pub purge_closed_orders_buffer_mins: Option<u32>,
pub purge_closed_positions_buffer_mins: Option<u32>,
pub purge_account_events_lookback_mins: Option<u32>,
pub purge_from_database: bool,
}Expand description
Configuration for execution manager.
Fields
trader_id: TraderIdThe trader ID for generated orders.
reconciliation: boolIf reconciliation is active at start-up.
lookback_mins: Option<u64>Number of minutes to look back during reconciliation.
reconciliation_instrument_ids: IndexSet<InstrumentId>Instrument IDs to include during reconciliation (empty => all).
filter_unclaimed_external: boolWhether to filter unclaimed external orders.
filter_position_reports: boolWhether to filter position status reports during reconciliation.
filtered_client_order_ids: IndexSet<ClientOrderId>Client order IDs excluded from reconciliation.
generate_missing_orders: boolWhether to generate missing orders from reports.
inflight_check_interval_ms: u32The interval (milliseconds) between checking whether in-flight orders have exceeded their threshold.
inflight_threshold_ms: u64Threshold in milliseconds for inflight order checks.
inflight_max_retries: u32Maximum number of retries for inflight checks.
open_check_interval_secs: Option<f64>The interval (seconds) between checks for open orders at the venue.
open_check_lookback_mins: Option<u64>The lookback minutes for open order checks.
open_check_threshold_ns: u64Threshold in nanoseconds before acting on venue discrepancies for open orders.
open_check_missing_retries: u32Maximum retries before resolving an open order missing at the venue.
open_check_open_only: boolWhether open-order polling should only request open orders from the venue.
max_single_order_queries_per_cycle: u32The maximum number of single-order queries per consistency check cycle.
single_order_query_delay_ms: u32The delay (milliseconds) between consecutive single-order queries.
position_check_interval_secs: Option<f64>The interval (seconds) between checks for open positions at the venue.
position_check_lookback_mins: u64The lookback minutes for position consistency checks.
position_check_threshold_ns: u64Threshold in nanoseconds before acting on venue discrepancies for positions.
position_check_retries: u32Maximum retries before stopping position discrepancy reconciliation.
purge_closed_orders_buffer_mins: Option<u32>The time buffer (minutes) before closed orders can be purged.
purge_closed_positions_buffer_mins: Option<u32>The time buffer (minutes) before closed positions can be purged.
purge_account_events_lookback_mins: Option<u32>The time buffer (minutes) before account events can be purged.
purge_from_database: boolIf purge operations should also delete from the backing database.
Implementations
Sourceimpl ExecutionManagerConfig
impl ExecutionManagerConfig
Sourcepub fn with_trader_id(self, trader_id: TraderId) -> Self
pub fn with_trader_id(self, trader_id: TraderId) -> Self
Sets the trader ID on the configuration.