pub struct LiveDataEngineConfig {Show 13 fields
pub time_bars_build_with_no_updates: bool,
pub time_bars_timestamp_on_close: bool,
pub time_bars_skip_first_non_full_bar: bool,
pub time_bars_interval_type: BarIntervalType,
pub time_bars_build_delay: u64,
pub time_bars_origin_offset: HashMap<String, u64>,
pub validate_data_sequence: bool,
pub buffer_deltas: bool,
pub emit_quotes_from_book: bool,
pub emit_quotes_from_book_depths: bool,
pub external_clients: Option<Vec<ClientId>>,
pub debug: bool,
pub qsize: u32,
}Expand description
Configuration for live data engines.
Fields
time_bars_build_with_no_updates: boolIf time bar aggregators will build and emit bars with no new market updates.
time_bars_timestamp_on_close: boolIf time bar aggregators will timestamp ts_event on bar close.
If false, the aggregator will timestamp on bar open.
time_bars_skip_first_non_full_bar: boolIf time bar aggregators will skip emitting a bar when aggregation starts mid-interval.
time_bars_interval_type: BarIntervalTypeThe interval semantics used for time aggregation.
time_bars_build_delay: u64The build delay (microseconds) before a time bar is emitted.
time_bars_origin_offset: HashMap<String, u64>A mapping of time bar aggregation types to their origin time offsets (nanoseconds).
Keys are BarAggregation variant names, values are offset durations in nanoseconds.
validate_data_sequence: boolIf data timestamp sequencing should be validated and handled.
buffer_deltas: boolIf order book deltas should be buffered until the F_LAST flag is set for a delta.
emit_quotes_from_book: boolIf quotes should be emitted on order book updates.
emit_quotes_from_book_depths: boolIf quotes should be emitted on order book depth updates.
external_clients: Option<Vec<ClientId>>Client IDs declared for external stream processing.
The data engine will not attempt to send data commands to these client IDs.
debug: boolIf debug mode is active (will provide extra debug logging).
qsize: u32The queue size for the engine’s internal queue buffers.
Not implemented on the current live runtime; validate_runtime_support rejects
any value other than the default.
Implementations
Sourceimpl LiveDataEngineConfig
impl LiveDataEngineConfig
Sourcepub fn builder() -> LiveDataEngineConfigBuilder
pub fn builder() -> LiveDataEngineConfigBuilder
Create an instance of LiveDataEngineConfig using the builder syntax