Struct LiveExecEngineConfigBuilder Copy item path Source pub struct LiveExecEngineConfigBuilder<S: State = Empty> { }Expand description Use builder syntax to set the inputs and finish with build() .
Finish building and return the requested object
Optional (Some / Option setters).
Default: true.
If the cache should be loaded on initialization.
Optional (Some / Option setters).
Default: true.
If the cache should be loaded on initialization.
Optional (Some / Option setters).
Default: false.
If order state snapshot lists should be persisted to a backing database.
Not implemented on the current live runtime; validate_runtime_support rejects
any value other than the default because the live kernel does not yet wire a
cache database adapter.
Optional (Some / Option setters).
Default: false.
If order state snapshot lists should be persisted to a backing database.
Not implemented on the current live runtime; validate_runtime_support rejects
any value other than the default because the live kernel does not yet wire a
cache database adapter.
Optional (Some / Option setters).
Default: false.
If position state snapshot lists should be persisted to a backing database.
Not implemented on the current live runtime; validate_runtime_support rejects
any value other than the default because the live kernel does not yet wire a
cache database adapter.
Optional (Some / Option setters).
Default: false.
If position state snapshot lists should be persisted to a backing database.
Not implemented on the current live runtime; validate_runtime_support rejects
any value other than the default because the live kernel does not yet wire a
cache database adapter.
Optional (Some / Option setters).
The interval (seconds) at which additional position state snapshots are persisted.
If None then no additional snapshots will be taken.
Optional (Some / Option setters).
The interval (seconds) at which additional position state snapshots are persisted.
If None then no additional snapshots will be taken.
Optional (Some / Option setters).
Client IDs declared for external stream processing.
The execution engine will not attempt to send trading commands to these client
IDs, assuming an external process consumes them from the bus.
Optional (Some / Option setters).
Client IDs declared for external stream processing.
The execution engine will not attempt to send trading commands to these client
IDs, assuming an external process consumes them from the bus.
Optional (Some / Option setters).
Default: false.
If debug mode is active (will provide extra debug logging).
Optional (Some / Option setters).
Default: false.
If debug mode is active (will provide extra debug logging).
Optional (Some / Option setters).
Default: true.
If reconciliation is active at start-up.
Optional (Some / Option setters).
Default: true.
If reconciliation is active at start-up.
Optional (Some / Option setters).
Default: 10.0.
The delay (seconds) before starting reconciliation at startup.
Optional (Some / Option setters).
Default: 10.0.
The delay (seconds) before starting reconciliation at startup.
Optional (Some / Option setters).
The maximum lookback minutes to reconcile state for.
Optional (Some / Option setters).
The maximum lookback minutes to reconcile state for.
Optional (Some / Option setters).
Specific instrument IDs to reconcile (if None, reconciles all).
Optional (Some / Option setters).
Specific instrument IDs to reconcile (if None, reconciles all).
Optional (Some / Option setters).
Default: false.
If unclaimed order events with an EXTERNAL strategy ID should be filtered/dropped.
Optional (Some / Option setters).
Default: false.
If unclaimed order events with an EXTERNAL strategy ID should be filtered/dropped.
Optional (Some / Option setters).
Default: false.
If position status reports are filtered from reconciliation.
Optional (Some / Option setters).
Default: false.
If position status reports are filtered from reconciliation.
Optional (Some / Option setters).
Client order IDs to filter from reconciliation.
Optional (Some / Option setters).
Client order IDs to filter from reconciliation.
Optional (Some / Option setters).
Default: true.
If MARKET order events will be generated during reconciliation to align discrepancies.
Optional (Some / Option setters).
Default: true.
If MARKET order events will be generated during reconciliation to align discrepancies.
Optional (Some / Option setters).
Default: 2_000.
The interval (milliseconds) between checking whether in-flight orders have exceeded their threshold.
Optional (Some / Option setters).
Default: 2_000.
The interval (milliseconds) between checking whether in-flight orders have exceeded their threshold.
Optional (Some / Option setters).
Default: 5_000.
The threshold (milliseconds) beyond which an in-flight order’s status is checked with the venue.
Optional (Some / Option setters).
Default: 5_000.
The threshold (milliseconds) beyond which an in-flight order’s status is checked with the venue.
Optional (Some / Option setters).
Default: 5.
The number of retry attempts for verifying in-flight order status.
Optional (Some / Option setters).
Default: 5.
The number of retry attempts for verifying in-flight order status.
Optional (Some / Option setters).
The interval (seconds) between checks for open orders at the venue.
Optional (Some / Option setters).
The interval (seconds) between checks for open orders at the venue.
Optional (Some / Option setters).
The lookback minutes for open order checks.
When None, the check is unbounded (no time filter).
Optional (Some / Option setters).
The lookback minutes for open order checks.
When None, the check is unbounded (no time filter).
Optional (Some / Option setters).
Default: 5_000.
The minimum elapsed time (milliseconds) since an order update before acting on discrepancies.
Optional (Some / Option setters).
Default: 5_000.
The minimum elapsed time (milliseconds) since an order update before acting on discrepancies.
Optional (Some / Option setters).
Default: 5.
The number of retries for missing open orders.
Optional (Some / Option setters).
Default: 5.
The number of retries for missing open orders.
Optional (Some / Option setters).
Default: true.
If the check_open_orders requests only currently open orders from the venue.
Optional (Some / Option setters).
Default: true.
If the check_open_orders requests only currently open orders from the venue.
Optional (Some / Option setters).
Default: 10.
The maximum number of single-order queries per consistency check cycle.
Optional (Some / Option setters).
Default: 10.
The maximum number of single-order queries per consistency check cycle.
Optional (Some / Option setters).
Default: 100.
The delay (milliseconds) between consecutive single-order queries.
Optional (Some / Option setters).
Default: 100.
The delay (milliseconds) between consecutive single-order queries.
Optional (Some / Option setters).
The interval (seconds) between checks for open positions at the venue.
Optional (Some / Option setters).
The interval (seconds) between checks for open positions at the venue.
Optional (Some / Option setters).
Default: 60.
The lookback minutes for position consistency checks.
Optional (Some / Option setters).
Default: 60.
The lookback minutes for position consistency checks.
Optional (Some / Option setters).
Default: 5_000.
The minimum elapsed time (milliseconds) since a position update before acting on discrepancies.
Optional (Some / Option setters).
Default: 5_000.
The minimum elapsed time (milliseconds) since a position update before acting on discrepancies.
Optional (Some / Option setters).
Default: 3.
The maximum number of reconciliation attempts for a position discrepancy.
Optional (Some / Option setters).
Default: 3.
The maximum number of reconciliation attempts for a position discrepancy.
Optional (Some / Option setters).
The interval (minutes) between purging closed orders from the in-memory cache.
Optional (Some / Option setters).
The interval (minutes) between purging closed orders from the in-memory cache.
Optional (Some / Option setters).
The time buffer (minutes) before closed orders can be purged.
Optional (Some / Option setters).
The time buffer (minutes) before closed orders can be purged.
Optional (Some / Option setters).
The interval (minutes) between purging closed positions from the in-memory cache.
Optional (Some / Option setters).
The interval (minutes) between purging closed positions from the in-memory cache.
Optional (Some / Option setters).
The time buffer (minutes) before closed positions can be purged.
Optional (Some / Option setters).
The time buffer (minutes) before closed positions can be purged.
Optional (Some / Option setters).
The interval (minutes) between purging account events from the in-memory cache.
Optional (Some / Option setters).
The interval (minutes) between purging account events from the in-memory cache.
Optional (Some / Option setters).
The time buffer (minutes) before account events can be purged.
Optional (Some / Option setters).
The time buffer (minutes) before account events can be purged.
Optional (Some / Option setters).
Default: false.
If purge operations should also delete from the backing database.
Optional (Some / Option setters).
Default: false.
If purge operations should also delete from the backing database.
Optional (Some / Option setters).
The interval (seconds) between auditing own books against public order books.
Optional (Some / Option setters).
The interval (seconds) between auditing own books against public order books.
Optional (Some / Option setters).
Default: 100_000.
The queue size for the engine’s internal queue buffers.
Optional (Some / Option setters).
Default: 100_000.
The queue size for the engine’s internal queue buffers.
Optional (Some / Option setters).
Default: false.
If order fills exceeding order quantity are allowed (logs warning instead of raising).
Useful when position reconciliation races with exchange fill events.
Optional (Some / Option setters).
Default: false.
If order fills exceeding order quantity are allowed (logs warning instead of raising).
Useful when position reconciliation races with exchange fill events.
Optional (Some / Option setters).
Default: false.
If the execution engine should maintain own/user order books based on commands and events.
Optional (Some / Option setters).
Default: false.
If the execution engine should maintain own/user order books based on commands and events.
Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From <T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.