pub struct QueueMonitorConfig {
pub queue_depth_trigger: usize,
pub queue_depth_clear: usize,
pub mean_dispatch_ns_trigger: u64,
pub mean_dispatch_ns_clear: u64,
}Expand description
Configuration for runner queue pressure monitoring.
Fields
queue_depth_trigger: usizeQueue depth that triggers a backlogged state.
queue_depth_clear: usizeQueue depth at or below which a backlogged state clears.
mean_dispatch_ns_trigger: u64Mean dispatch time that triggers a slow state, in nanoseconds.
mean_dispatch_ns_clear: u64Mean dispatch time at or below which a slow state clears, in nanoseconds.
Implementations
Sourceimpl QueueMonitorConfig
impl QueueMonitorConfig
Sourcepub fn builder() -> QueueMonitorConfigBuilder
pub fn builder() -> QueueMonitorConfigBuilder
Create an instance of QueueMonitorConfig using the builder syntax